=== modified file 'bzrlib/revisiontree.py'
--- bzrlib/revisiontree.py	2008-10-12 15:26:50 +0000
+++ bzrlib/revisiontree.py	2008-10-12 15:38:00 +0000
@@ -63,9 +63,6 @@
         """Return the revision id associated with this tree."""
         return self._revision_id
 
-    def get_file_lines(self, file_id):
-        return osutils.split_lines(self.get_file_text(file_id))
-
     def get_file_text(self, file_id, path=None):
         return list(self.iter_files_bytes([(file_id, None)]))[0][1]
 

=== modified file 'bzrlib/tests/tree_implementations/test_tree.py'
--- bzrlib/tests/tree_implementations/test_tree.py	2008-10-12 15:26:50 +0000
+++ bzrlib/tests/tree_implementations/test_tree.py	2008-10-12 15:38:00 +0000
@@ -173,6 +173,15 @@
         # test read by path
         self.assertEqual('foobar\n', tree.get_file_text('a-id', path='a'))
 
+    def test_get_file_lines(self):
+        work_tree = self.make_branch_and_tree('wt')
+        tree = self.get_tree_no_parents_abc_content_2(work_tree)
+        tree.lock_read()
+        self.addCleanup(tree.unlock)
+        # test read by file-id
+        self.assertEqual(['foobar\n'], tree.get_file_lines('a-id'))
+        # test read by path
+        self.assertEqual(['foobar\n'], tree.get_file_lines('a-id', path='a'))
 
 class TestExtractFilesBytes(TestCaseWithTree):
 

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2008-10-12 15:26:50 +0000
+++ bzrlib/tree.py	2008-10-12 15:38:00 +0000
@@ -277,6 +277,19 @@
         finally:
             my_file.close()
 
+    def get_file_lines(self, file_id, path=None):
+        """Return the content of a file, as lines.
+
+        :param file_id: The file_id of the file.
+        :param path: The path of the file.
+        If both file_id and path are supplied, an implementation may use
+        either one.
+
+        osutils.split_lines is always used, rather than calling file.readlines,
+        because the behavior of file.readlines may differ by platform.
+        """
+        return osutils.split_lines(self.get_file_text(file_id, path))
+
     def get_file_mtime(self, file_id, path=None):
         """Return the modification time for a file.
 

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2008-10-12 15:26:50 +0000
+++ bzrlib/workingtree_4.py	2008-10-12 15:38:00 +0000
@@ -1625,9 +1625,6 @@
     def get_file(self, file_id, path=None):
         return StringIO(self.get_file_text(file_id))
 
-    def get_file_lines(self, file_id):
-        return osutils.split_lines(self.get_file_text(file_id))
-
     def get_file_size(self, file_id):
         """See Tree.get_file_size"""
         return self.inventory[file_id].text_size

